@@ -26,10 +26,8 @@ impl Shape for Polygon {
     fn support_point(&self, direction: Vector2) -> Vector2 {
         get_max_point(self.vertices.iter(), direction, self.position())
     }
-}
-impl std::fmt::Display for Polygon {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result
-    {
+
+    fn display_fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "Polygon pos({0}), vertices_count: {1}", self.position, self.vertices.len())
     }
 }
